==> freecad_0.13.2935-dfsg.orig.tar.xz: freecad-0.13.2935-dfsg/src/Mod/Points/Gui/Resources/translations/Points_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS>
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="+104"/>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <source>Export points...</source>
      <translation>Pontok exportálása...</translation>
    </message>
    <message>
      <source>Exports a point cloud</source>
      <translation>Pontfelhő exportálása</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <source>Import points...</source>
      <translation>Pontok importálása...</translation>
    </message>
    <message>
      <source>Imports a point cloud</source>
      <translation>Pontfelhő importálása</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <source>Cut point cloud</source>
      <translation>Pontfelhő kivágása</translation>
    </message>
    <message>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Pontfelhő kivágása egy kiválaszott polygonnal</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <source>Transform Points</source>
      <translation>Pontok átalakítása</translation>
    </message>
    <message>
      <source>Test to transform a point cloud</source>
      <translation>Pontfelhő átalakításának tesztje</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>ASCII pontok importálása</translation>
    </message>
    <message>
      <source>Template:</source>
      <translation>Sablon:</translation>
    </message>
    <message>
      <source>Special lines</source>
      <translation>Speciális vonalak</translation>
    </message>
    <message>
      <source>First line:</source>
      <translation>Első vonal:</translation>
    </message>
    <message>
      <source>Ignore</source>
      <translation>Kihagy</translation>
    </message>
    <message>
      <source>Cluster by lines starting with:</source>
      <translation>Vonallal kezdődő fürt:</translation>
    </message>
    <message>
      <source>Ignore lines starting with:</source>
      <translation>Kezdő vonalak kihagyása:</translation>
    </message>
    <message>
      <source>Point format</source>
      <translation>Pont formátum</translation>
    </message>
    <message>
      <source>Number separator:</source>
      <translation>Szám elválasztó jel:</translation>
    </message>
    <message>
      <source>Points format:</source>
      <translation>Pont formátum:</translation>
    </message>
    <message>
      <source>Next block:</source>
      <translation>Következő blokk:</translation>
    </message>
    <message>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <source>none</source>
      <translation>egyik sem</translation>
    </message>
    <message>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (normál vektor)</translation>
    </message>
    <message>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (normál vektor 2D)</translation>
    </message>
    <message>
      <source>R,G,B (color)</source>
      <translation>R,G,B (szín)</translation>
    </message>
    <message>
      <source>I (Gray value)</source>
      <translation>I (szürkeárnyalat-érték)</translation>
    </message>
    <message>
      <source>Preview</source>
      <translation>Előnézet</translation>
    </message>
    <message>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <source>Number of points</source>
      <translation>Pontok száma</translation>
    </message>
    <message>
      <source>Number of previewed lines:</source>
      <translation>Előnézeti sorok száma:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-84"/>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>Ascii pontok (*.asc);;Minden fájl (*.*)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Pont eszközök</translation>
    </message>
    <message>
      <source>&amp;Points</source>
      <translation>&amp;Pontok</translation>
    </message>
  </context>
</TS>

==> freecad_0.14.3702+dfsg.orig.tar.xz: freecad-0.14.3702/src/Mod/Points/Gui/Resources/translations/Points_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>CmdPointsExport</name>
    <message>
      <location filename="../../Command.cpp" line="+104"/>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Export points...</source>
      <translation>Pontok exportálása...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <location line="+1"/>
      <source>Exports a point cloud</source>
      <translation>Pontfelhő exportálása</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsImport</name>
    <message>
      <location line="-47"/>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Import points...</source>
      <translation>Pontok importálása...</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <location line="+1"/>
      <source>Imports a point cloud</source>
      <translation>Pontfelhő importálása</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsPolyCut</name>
    <message>
      <location line="+122"/>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Cut point cloud</source>
      <translation>Pontfelhő kivágása</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <location line="+1"/>
      <source>Cuts a point cloud with a picked polygon</source>
      <translation>Pontfelhő kivágása egy kiválaszott polygonnal</translation>
    </message>
  </context>
  <context>
    <name>CmdPointsTransform</name>
    <message>
      <location line="-39"/>
      <source>Points</source>
      <translation>Pontok</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Transform Points</source>
      <translation>Pontok átalakítása</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+1"/>
      <location line="+1"/>
      <source>Test to transform a point cloud</source>
      <translation>Pontfelhő átalakításának tesztje</translation>
    </message>
  </context>
  <context>
    <name>PointsGui::DlgPointsRead</name>
    <message>
      <location filename="../../DlgPointsRead.ui" line="+14"/>
      <source>ASCII points import</source>
      <translation>ASCII pontok importálása</translation>
    </message>
    <message>
      <location line="+20"/>
      <source>Template:</source>
      <translation>Sablon:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Special lines</source>
      <translation>Speciális vonalak</translation>
    </message>
    <message>
      <location line="+42"/>
      <source>First line:</source>
      <translation>Első vonal:</translation>
    </message>
    <message>
      <location line="+12"/>
      <source>Ignore</source>
      <translation>Kihagy</translation>
    </message>
    <message>
      <location line="-21"/>
      <source>Cluster by lines starting with:</source>
      <translation>Vonallal kezdődő fürt:</translation>
    </message>
    <message>
      <location line="-7"/>
      <source>Ignore lines starting with:</source>
      <translation>Kezdő vonalak kihagyása:</translation>
    </message>
    <message>
      <location line="+54"/>
      <source>Point format</source>
      <translation>Pont formátum</translation>
    </message>
    <message>
      <location line="+78"/>
      <source>Number separator:</source>
      <translation>Szám elválasztó jel:</translation>
    </message>
    <message>
      <location line="+98"/>
      <source>Points format:</source>
      <translation>Pont formátum:</translation>
    </message>
    <message>
      <location line="-91"/>
      <location line="+7"/>
      <location line="+7"/>
      <source>Next block:</source>
      <translation>Következő blokk:</translation>
    </message>
    <message>
      <location line="+40"/>
      <source>,</source>
      <translation>,</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>;</source>
      <translation>;</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\t</source>
      <translation>\t</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>\w</source>
      <translation>\w</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>X,Y,Z</source>
      <translation>X,Y,Z</translation>
    </message>
    <message>
      <location line="+5"/>
      <source>X,Y</source>
      <translation>X,Y</translation>
    </message>
    <message>
      <location line="-147"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>none</source>
      <translation>egyik sem</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,J,K (normal vector)</source>
      <translation>I, J, K (normál vektor)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I,K (normal vector 2D)</source>
      <translation>I, K (normál vektor 2D)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>R,G,B (color)</source>
      <translation>R,G,B (szín)</translation>
    </message>
    <message>
      <location line="-81"/>
      <location line="+29"/>
      <location line="+57"/>
      <source>I (Gray value)</source>
      <translation>I (szürkeárnyalat-érték)</translation>
    </message>
    <message>
      <location line="+61"/>
      <source>Preview</source>
      <translation>Előnézet</translation>
    </message>
    <message>
      <location line="+34"/>
      <source>100</source>
      <translation>100</translation>
    </message>
    <message>
      <location line="-238"/>
      <source>Number of points</source>
      <translation>Pontok száma</translation>
    </message>
    <message>
      <location line="+231"/>
      <source>Number of previewed lines:</source>
      <translation>Előnézeti sorok száma:</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <location filename="../../Command.cpp" line="-84"/>
      <location line="+43"/>
      <source>Ascii Points (*.asc);;All Files (*.*)</source>
      <translation>Ascii pontok (*.asc);;Minden fájl (*.*)</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+37"/>
      <source>Points tools</source>
      <translation>Pont eszközök</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>&amp;Points</source>
      <translation>&amp;Pontok</translation>
    </message>
  </context>
</TS>
